%define anolis_release 2
# Add readline edditing in pcre2test tool
%bcond_without pcre2_enables_readline

# Disable SELinux-frindly JIT allocator because it seems not to be fork-safe,
# https://bugs.exim.org/show_bug.cgi?id=1749#c45
%bcond_with pcre2_enables_sealloc

# This is stable release:
Name:       pcre2
Version:    10.42
Release:    %{anolis_release}%{?dist}
Summary:    Perl-compatible regular expression library
License:    BSD
URL:        https://www.pcre.org/
Source0:    https://github.com/PCRE2Project/pcre2/releases/download/%{name}-%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  coreutils
BuildRequires:  gcc
BuildRequires:  gnupg2
BuildRequires:  make
%if %{with pcre2_enables_readline}
BuildRequires:  readline-devel
%endif
BuildRequires:  sed
Requires:       %{name}-syntax = %{version}-%{release}
Provides:       bundled(sljit)

%description
PCRE2 is a re-working of the original PCRE (Perl-compatible regular
expression) library to provide an entirely new API.

PCRE2 is written in C, and it has its own API. There are three sets of
functions, one for the 8-bit library, which processes strings of bytes, one
for the 16-bit library, which processes strings of 16-bit values, and one for
the 32-bit library, which processes strings of 32-bit values. There are no C++
wrappers. This package provides support for strings in 8-bit and UTF-8
encodings. Install %{name}-utf16 or %{name}-utf32 packages for the other ones.

The distribution does contain a set of C wrapper functions for the 8-bit
library that are based on the POSIX regular expression API (see the pcre2posix
man page). These can be found in a library called libpcre2posix. Note that
this just provides a POSIX calling interface to PCRE2; the regular expressions
themselves still follow Perl syntax and semantics. The POSIX API is
restricted, and does not give full access to all of PCRE2's facilities.

%package utf16
Summary:    UTF-16 variant of PCRE2
Provides:   bundled(sljit)
Requires:   %{name}-syntax = %{version}-%{release}
Conflicts:  %{name} < 10.21

%description utf16
This is PCRE2 library working on UTF-16 strings.

%package utf32
Summary:    UTF-32 variant of PCRE2
Provides:   bundled(sljit)
Requires:   %{name}-syntax = %{version}-%{release}
Conflicts:  %{name} < 10.21

%description utf32
This is PCRE2 library working on UTF-32 strings.

%package devel
Summary:    Development files for %{name}
Requires:   %{name} = %{version}-%{release}
Requires:   %{name}-utf16 = %{version}-%{release}
Requires:   %{name}-utf32 = %{version}-%{release}

%description devel
Development files (headers, libraries for dynamic linking, documentation)
for %{name}.  The header file for the POSIX-style functions is called
pcre2posix.h.

%package static
Summary:    Static library for %{name}
Requires:   %{name}-devel = %{version}-%{release}
Provides:   bundled(sljit)

%description static
Library for static linking for %{name}.

%package syntax
Summary:    Documentation for PCRE2 regular expressions
BuildArch:  noarch
Conflicts:  %{name}-devel < 10.34-8

%description syntax
This is a set of manual pages that document a syntax of the regular
expressions implemented by the PCRE2 library.

%package tools
Summary:    Auxiliary utilities for %{name}
# pcre2test (linked to GNU readline):   BSD (linked to GPLv3+)
License:    BSD and GPLv3+
Requires:   %{name} = %{version}-%{release}

%description tools
Utilities demonstrating PCRE2 capabilities like pcre2grep or pcre2test.

%prep
%autosetup -n %{name}-%{version} -p1

%build
# There is a strict-aliasing problem on PPC64, bug #881232
%configure \
%ifarch loongarch64
    --disable-jit \
%else
    --enable-jit \
%endif
    --enable-pcre2grep-jit \
    --disable-bsr-anycrlf \
    --disable-coverage \
    --disable-ebcdic \
    --disable-fuzz-support \
%if %{with pcre2_enables_sealloc}
    --enable-jit-sealloc \
%else
    --disable-jit-sealloc \
%endif
    --disable-never-backslash-C \
    --enable-newline-is-lf \
    --enable-pcre2-8 \
    --enable-pcre2-16 \
    --enable-pcre2-32 \
    --enable-pcre2grep-callout \
    --enable-pcre2grep-callout-fork \
    --disable-pcre2grep-libbz2 \
    --disable-pcre2grep-libz \
    --disable-pcre2test-libedit \
%if %{with pcre2_enables_readline}
    --enable-pcre2test-libreadline \
%else
    --disable-pcre2test-libreadline \
%endif
    --enable-percent-zt \
    --disable-rebuild-chartables \
    --enable-shared \
    --disable-silent-rules \
    --enable-static \
    --enable-unicode \
    --disable-valgrind
%{make_build}

%install
%{make_install}
# These are handled by %%doc in %%files
rm -rf $RPM_BUILD_ROOT%{_docdir}/pcre2

%generate_compatibility_deps

%check
%make_build check VERBOSE=yes

%files
%{_libdir}/libpcre2-8.so.0*
%{abidir}/libpcre2-8*.dump
%{_libdir}/libpcre2-posix.so.3*
%{abidir}/libpcre2-posix*.dump

%files utf16
%{_libdir}/libpcre2-16.so.0*
%{abidir}/libpcre2-16*.dump

%files utf32
%{_libdir}/libpcre2-32.so.0*
%{abidir}/libpcre2-32*.dump

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*.h
%{_mandir}/man1/pcre2-config.*
%{_mandir}/man3/pcre2_*
%{_mandir}/man3/pcre2api.*
%{_mandir}/man3/pcre2build.*
%{_mandir}/man3/pcre2callout.*
%{_mandir}/man3/pcre2convert.*
%{_mandir}/man3/pcre2demo.*
%{_mandir}/man3/pcre2jit.*
%{_mandir}/man3/pcre2posix.*
%{_mandir}/man3/pcre2sample.*
%{_mandir}/man3/pcre2serialize*
%{_bindir}/pcre2-config
%doc doc/*.txt doc/html
%doc README HACKING ./src/pcre2demo.c

%files static
%{_libdir}/*.a
%license COPYING LICENCE

%files syntax
%dir %{abidir}
%license COPYING LICENCE
%doc AUTHORS ChangeLog NEWS
%{_mandir}/man3/pcre2.*
%{_mandir}/man3/pcre2compat.*
%{_mandir}/man3/pcre2limits.*
%{_mandir}/man3/pcre2matching.*
%{_mandir}/man3/pcre2partial.*
%{_mandir}/man3/pcre2pattern.*
%{_mandir}/man3/pcre2perform.*
%{_mandir}/man3/pcre2syntax.*
%{_mandir}/man3/pcre2unicode.*

%files tools
%{_bindir}/pcre2grep
%{_bindir}/pcre2test
%{abidir}/pcre2grep-option.list
%{abidir}/pcre2test-option.list
%{_mandir}/man1/pcre2grep.*
%{_mandir}/man1/pcre2test.*

%changelog
* Wed Aug 16 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 10.42-2
- fix build error for loongarch64

* Mon Jan 2 2023 Funda Wang <fundawang@yeah.net> - 10.42-1
- New version 10.42

* Fri Oct 14 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 10.40-2
- optimise spec file

* Tue Aug 30 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 10.40-1
- update to 10.40

* Tue Mar  8 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 10.39-1
- Init version from upstream v10.39
